PDFstream
=========

[![test](https://github.com/st3107/pdfstream/workflows/test/badge.svg?branch=master)](https://github.com/st3107/pdfstream/actions?query=branch%3Amaster+workflow%3Atest)
[![codecov](https://codecov.io/gh/st3107/pdfstream/branch/master/graph/badge.svg?token=ZFXWWDWQW8)](https://codecov.io/gh/st3107/pdfstream)
[![Release](https://anaconda.org/st3107/pdfstream/badges/version.svg)](https://anaconda.org/st3107/pdfstream)

The data analysis toolbox for the study on pair distribution function (PDF).

-   Free software: 3-clause BSD license
-   Documentation: <https://st3107.github.io/pdfstream>.
